{% extends "layout.html" %} {% block title %}Recent changes{% endblock %} {% block head %}
{% endblock %} {% block breadcrumb %}
- Recent changes {% endblock %} {% block hamburger %}
  {% endblock %} {% block body %}

  These are the recent changes to the tags on the website. The website is regularly updated, but it is possible that the repository is slightly ahead.

  {% for commit in commits %}
  {{ commit.time.strftime("%b %-d, %Y") }}
    {{ commit.hash[0:7] }}

        {{ commit.log.splitlines()[0] }}

    {% if commit.tags | length > 20 %}

    More than 20 tags were affected, see the commit for more information. {% else %}

    {% for tag in commit.tags %}
    - {{ tag.type | capitalize }} {{ tag.ref }} {# {% for parent in tag.breadcrumb %} {{ parent.type | capitalize }} {{ parent.ref }}{% if parent.name %}: {{ parent.name }}{% endif %}{% if not loop.last %}, {% endif %} {% endfor %} #} {% endfor %}
    {% endif %} {% endfor %}
  {% endblock %} {% block sidebar %}
  {% endblock %}